package org.mathcs.ibookmark;

/**
 * Class to contain a list of bookmarks that mediates between the list and the
 * view onto the list (a ListView). Provides methods to add, delete, and edit
 * members of the list but has no UI.
 * 
 * @author Bert Wachsmuth
 * @version 1.0 (10/2013)
 */
import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Toast;

public class BookmarkAdapter extends BaseAdapter
{
	private ArrayList<Bookmark> data;
	private Context context;
	
	private boolean isDirty;
	
	public BookmarkAdapter(Context context)
	{
		super();
		this.context = context;
		this.data = new ArrayList<Bookmark>();
		this.isDirty = false;
	}

	public void add(Bookmark item)
	{
		data.add(item);
		isDirty = true;
	}
	
	public Bookmark get(int position)
	{
		return (Bookmark)data.get(position);
	}
	
	public void remove(int position)
	{
		data.remove(position);
		isDirty = true;
	}
	
	@Override
	public int getCount()
	{
		return data.size();
	}

	@Override
	public Object getItem(int position)
	{
		return data.get(position);
	}

	@Override
	public long getItemId(int position)
	{
		return 0;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent)
	{
		BookmarkView view = null;
		
		if (convertView != null)
			view = (BookmarkView)convertView;
		else
			view = new BookmarkView(context);
		
		view.setData(data.get(position));
		return view;
	}

	public boolean isDirty()
	{
		return isDirty;
	}
	
	public void saveBookmarks(PrintWriter out) throws IOException
	{
		// first writing version info
		out.println(BookmarkActivity.VERSION);
		// next writing number of bookmark items
		out.println(data.size());
		// finally reading in the bookmark items
		for (int i = 0; i < data.size(); i++)
			data.get(i).save(out);
		isDirty = false;
	}
	
	public void loadBookmarks(BufferedReader in) throws IOException
	{
		data.clear();
		String ver = in.readLine();
		if (ver.equals(BookmarkActivity.VERSION))
		{
			int size = Integer.parseInt(in.readLine());
			for (int i = 0; i < size; i++)
				data.add(new Bookmark(in));
			isDirty = false;
		}
		else
			Toast.makeText(context, "Data file has wrong format. Contact help. ", Toast.LENGTH_SHORT).show();
	}
	
	public void deselectAll()
	{
		for (int i = 0; i < data.size(); i++)
			data.get(i).setSelected(false);
	}
}
